@@ -7,12 +7,12 @@
     A framework-independent wrapper for SQLAlchemy that makes it really easy
     to use.
 
-    :copyright: © 2012 by `Juan Pablo Scaletti <http://jpscaletti.com>`_.
+    :copyright: © 2012-2015 by `Juan Pablo Scaletti <http://jpscaletti.com>`_.
     :license: MIT, see LICENSE for more details.
 
 """
-from .main import SQLAlchemy  # noqa
+from .main import SQLAlchemy, BaseQuery  # noqa
 from .paginator import Paginator  # noqa
 
 
-__version__ = '1.2.3'
+__version__ = '1.3.1'
